
This repository has been archived in favor of [prompt-toolkit] and [ptvertmenu]

[prompt-toolkit]: https://github.com/prompt-toolkit/python-prompt-toolkit
[ptvertmenu]: https://github.com/lpenz/ptvertmenu/

